package core.api.controller;

import core.api.models.auth.SimpleStatusResponse;
import core.api.models.properties.PropertiesResponse;
import core.api.models.properties.PropertyInfo;
import core.api.models.properties.PropertyRequest;
import core.entities.PropertiesEntity;
import core.services.PropertyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

@CrossOrigin(origins = "*", maxAge = 3600)
@RestController
@RequestMapping("/api/settings")
public class SettingsController {

    @Autowired
    private PropertyService propertyService;

    @PreAuthorize("hasRole('ADMIN')")
    @PostMapping("/update")
    public ResponseEntity<?> updateSettings(@RequestBody PropertyRequest propertyRequest) {
        for(PropertyInfo propertyInfo : propertyRequest.getSettings()) {
            Optional<PropertiesEntity> propertiesEntity = propertyService.getPropertyEntityByName(propertyInfo.getProperty());
            propertiesEntity.ifPresent(property -> {
                property.setStatus(propertyInfo.isStatus());
                propertyService.savePropertyEntity(property);
            });
        }
        return ResponseEntity.ok(new SimpleStatusResponse("success"));
    }

    @PreAuthorize("hasRole('ADMIN')")
    @GetMapping("")
    public ResponseEntity<?> listSettings() {
        List<PropertyInfo> propertyInfoList = new ArrayList<>();
        for(PropertyService.PropertyName propertyName : PropertyService.PropertyName.values()) {
            Optional<PropertyInfo> propertyInfo = propertyService.getProperty(propertyName);
            propertyInfo.ifPresent(propertyInfoList::add);
        }
        return ResponseEntity.ok(new PropertiesResponse(propertyInfoList));
    }
}
