import {Component, Inject, OnInit} from '@angular/core';
import {FormControl, Validators} from "@angular/forms";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {TaskgroupEntityInfo, TaskgroupService} from "../../../api";
import {error} from "@angular/compiler/src/util";
import {MatSnackBar} from "@angular/material/snack-bar";
import {ActivatedRoute} from "@angular/router";
import {TaskgroupCreationData} from "./TaskgroupCreationData";

@Component({
  selector: 'app-taskgroup-creation',
  templateUrl: './taskgroup-creation.component.html',
  styleUrls: ['./taskgroup-creation.component.css']
})
export class TaskgroupCreationComponent implements OnInit {

  nameCtrl = new FormControl('', [Validators.required, Validators.maxLength(255)])
  pending: boolean = false

  constructor(private dialogRef: MatDialogRef<TaskgroupCreationComponent>,
              private taskgroupService: TaskgroupService,
              private snackbar: MatSnackBar,
              @Inject(MAT_DIALOG_DATA) public data: TaskgroupCreationData) { }

  ngOnInit(): void {
    if(this.data.taskgroup != undefined) {
      this.nameCtrl.setValue(this.data.taskgroup!.taskgroupName)
    }
  }

  cancel() {
    this.dialogRef.close();
  }

  save() {
    this.pending = true;
    if(this.data.taskgroup == undefined) {
      this.taskgroupService.taskgroupsPut({
        name: this.nameCtrl.value,
        parentID: this.data.taskgroupID,
      }).subscribe({
        next: resp => {
          this.pending = false;
          this.dialogRef.close(resp);
        },
        error: err => {
          this.pending = false;
          if(err.status == 409) {
            this.snackbar.open("Taskgroup already exists", "", {duration: 2000});
          } else {
            this.snackbar.open("An unexpected error occured", "");
          }
        }
      })
    } else {
      this.taskgroupService.taskgroupsTaskgroupIDPost(this.data.taskgroup!.taskgroupID, {
        name: this.nameCtrl.value,
        parentID: this.data.taskgroupID
      }).subscribe({
        next: resp => {
          this.pending = false;
          this.data.taskgroup!.taskgroupName = this.nameCtrl.value
          this.dialogRef.close(true);
        },
        error: err => {
          this.pending = false;
          if(err.status == 409) {
            this.snackbar.open("Taskgroup already exists", "", {duration: 2000});
          } else if(err.status == 403) {
            this.snackbar.open("No permission", "", {duration: 2000})
          } else if(err.status == 404) {
            this.snackbar.open("Not found", "", {duration: 2000});
          } else {
            this.snackbar.open("An unexpected error occured", "");
          }
        }
      })
    }
  }
}
